@@ -19,7 +19,9 @@ from tikit.tencentcloud.wedata.v20210820 import models as wedata_models
 from tikit.tencentcloud.emr.v20190103 import emr_client
 from tikit.tencentcloud.emr.v20190103 import models as emr_models
 from tikit.tencentcloud.common import credential
-from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
+from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import (
+    TencentCloudSDKException,
+)
 from hdfs.ext.kerberos import KerberosClient
 from tqdm import tqdm
 from tikit.tencentcloud.tione.v20211111 import models
@@ -29,13 +31,16 @@ KERBEROS = 1
 LDAP = 2
 SIMPLE = 3
 
+
 def _get_tmp_path():
     """
     返回随机生成的hdfs临时目录
     :return:    临时目录
     :rtype:     str
     """
-    folder = "".join(random.sample(string.ascii_letters + string.digits, random.randint(12, 20)))
+    folder = "".join(
+        random.sample(string.ascii_letters + string.digits, random.randint(12, 20))
+    )
     return "/tmp/tikit/%s" % folder
 
 
@@ -53,9 +58,18 @@ def _get_host_port(server):
     return parts
 
 
-def upload_to_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name, database="default", auth="CUSTOM",
-                           username=None,
-                           password=None, overwrite=False, partition=""):
+def upload_to_hive_by_hdfs(
+    local_path,
+    hdfs_url,
+    hive_server,
+    table_name,
+    database="default",
+    auth="CUSTOM",
+    username=None,
+    password=None,
+    overwrite=False,
+    partition="",
+):
     """把本地文件的数据导入到hive表中，hdfs作为中间存储。
     过程：先把本地文件上传到hdfs上，然后再从hdfs文件导入到hive中。
 
@@ -89,14 +103,32 @@ def upload_to_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name, databa
         hdfs_path = os.path.join(hdfs_path, os.path.basename(local_path))
     hdfs_client.upload(hdfs_path, local_path)
     try:
-        insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database, auth, username,
-                              password, overwrite, partition)
+        insert_hdfs_into_hive(
+            hdfs_path,
+            hive_server,
+            table_name,
+            database,
+            auth,
+            username,
+            password,
+            overwrite,
+            partition,
+        )
     finally:
         hdfs_client.delete(hdfs_tmp_path, True)
 
 
-def insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database="default", auth="CUSTOM", username=None,
-                          password=None, overwrite=False, partition=""):
+def insert_hdfs_into_hive(
+    hdfs_path,
+    hive_server,
+    table_name,
+    database="default",
+    auth="CUSTOM",
+    username=None,
+    password=None,
+    overwrite=False,
+    partition="",
+):
     """把hdfs的文件数据导入到hive表中。
 
     :param hdfs_path:       hdfs上的文件或者文件夹。文件夹中不能包含子文件夹。如：/tmp/file.csv
@@ -123,14 +155,20 @@ def insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database="default"
     :rtype:
     """
     hive_host, hive_port = _get_host_port(hive_server)
-    with hive.Connection(host=hive_host, port=hive_port, database=database,
-                         username=username, password=password, auth=auth) as conn:
+    with hive.Connection(
+        host=hive_host,
+        port=hive_port,
+        database=database,
+        username=username,
+        password=password,
+        auth=auth,
+    ) as conn:
         with conn.cursor() as cursor:
             sql = "LOAD DATA INPATH '{}' {} INTO TABLE {} {}".format(
                 hdfs_path,
                 "OVERWRITE" if overwrite else "",
                 table_name,
-                "" if partition == "" else "PARTITION (%s)" % partition
+                "" if partition == "" else "PARTITION (%s)" % partition,
             )
             cursor.execute(sql)
 
@@ -183,9 +221,18 @@ def insert_hdfs_into_hive(hdfs_path, hive_server, table_name, database="default"
 #     return local_path
 
 
-def export_from_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name="", sql="", database="default",
-                             auth="CUSTOM", username=None, password=None,
-                             row_format="row format delimited fields terminated by ','"):
+def export_from_hive_by_hdfs(
+    local_path,
+    hdfs_url,
+    hive_server,
+    table_name="",
+    sql="",
+    database="default",
+    auth="CUSTOM",
+    username=None,
+    password=None,
+    row_format="row format delimited fields terminated by ','",
+):
     """导出hive表到本地上，hdfs作为中间存储。对于大文件，这种方式比直接从hive表写到本地的效率更高。
     过程：先把hive导出到hdfs上，然后再从hdfs下载文件到本地。
 
@@ -217,7 +264,17 @@ def export_from_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name="", s
     tmp_path = _get_tmp_path()
     hdfs_path = os.path.join(tmp_path, "result")
     hdfs_client = HdfsClient(hdfs_url)
-    save_hive_to_hdfs(hdfs_path, hive_server, table_name, sql, database, auth, username, password, row_format)
+    save_hive_to_hdfs(
+        hdfs_path,
+        hive_server,
+        table_name,
+        sql,
+        database,
+        auth,
+        username,
+        password,
+        row_format,
+    )
     try:
         local_dir = os.path.dirname(local_path)
         if local_dir != "" and not os.path.exists(local_dir):
@@ -227,8 +284,17 @@ def export_from_hive_by_hdfs(local_path, hdfs_url, hive_server, table_name="", s
         hdfs_client.delete(hdfs_path, True)
 
 
-def save_hive_to_hdfs(hdfs_path, hive_server, table_name="", sql="", database="default", auth="CUSTOM",
-                      username=None, password=None, row_format="row format delimited fields terminated by ','"):
+def save_hive_to_hdfs(
+    hdfs_path,
+    hive_server,
+    table_name="",
+    sql="",
+    database="default",
+    auth="CUSTOM",
+    username=None,
+    password=None,
+    row_format="row format delimited fields terminated by ','",
+):
     """把hive表的数据导出到hdfs上
 
     :param hdfs_path:       目标hdfs的保存路径
@@ -255,23 +321,26 @@ def save_hive_to_hdfs(hdfs_path, hive_server, table_name="", sql="", database="d
     if table_name == "" and sql == "":
         raise Exception('"table_name" and "sql" cannot both be empty')
     hive_host, hive_port = _get_host_port(hive_server)
-    with hive.Connection(host=hive_host, port=hive_port, database=database,
-                         username=username, password=password, auth=auth) as conn:
+    with hive.Connection(
+        host=hive_host,
+        port=hive_port,
+        database=database,
+        username=username,
+        password=password,
+        auth=auth,
+    ) as conn:
         with conn.cursor() as cursor:
             # INSERT OVERWRITE [LOCAL] DIRECTORY directory1 SELECT ... FROM ...
             if sql == "":
-                execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} SELECT {} FROM {}".format(
-                    hdfs_path,
-                    row_format,
-                    "*",
-                    table_name
+                execute_sql = (
+                    "INSERT OVERWRITE DIRECTORY '{}' {} SELECT {} FROM {}".format(
+                        hdfs_path, row_format, "*", table_name
+                    )
                 )
                 cursor.execute(execute_sql)
             else:
                 execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} {}".format(
-                    hdfs_path,
-                    row_format,
-                    sql
+                    hdfs_path, row_format, sql
                 )
                 cursor.execute(execute_sql)
     return hdfs_path
@@ -302,37 +371,54 @@ class HiveInitial(object):
     def spark_hive_initial_wedata(self, wedata_id, source_account=None):
         """为spark初始化wedata hive（调用改方法后，就可以使用spark做hive操作）
 
-       :param wedata_id:       wedata数据源id
-       :type wedata_id:        int
-       :param source_account:     如果hive为系统源，则需要传使用账户uin
-       :type source_account:      str
-       :rtype:
-       """
-        datasource_conn_info = self._get_wedata_security_auth_info(wedata_id, source_account)
+        :param wedata_id:       wedata数据源id
+        :type wedata_id:        int
+        :param source_account:     如果hive为系统源，则需要传使用账户uin
+        :type source_account:      str
+        :rtype:
+        """
+        datasource_conn_info = self._get_wedata_security_auth_info(
+            wedata_id, source_account
+        )
         if datasource_conn_info["config_file_empty"]:
             raise Exception("Get hive-site.xml failed")
         if datasource_conn_info["auth_type"] == KERBEROS:
-            self._init_kerberos_ticket(datasource_conn_info["principal"], datasource_conn_info["keytab"])
+            self._init_kerberos_ticket(
+                datasource_conn_info["principal"], datasource_conn_info["keytab"]
+            )
 
     def hive_initial_wedata(self, wedata_id, source_account=None):
         """获取wedata hive连接句柄
 
-       :param wedata_id:       wedata数据源id
-       :type wedata_id:        int
-       :param source_account:     如果hive为系统源，则需要传使用账户uin
-       :type source_account:      str
-       :rtype:
-       """
-        datasource_conn_info = self._get_wedata_security_auth_info(wedata_id, source_account)
+        :param wedata_id:       wedata数据源id
+        :type wedata_id:        int
+        :param source_account:     如果hive为系统源，则需要传使用账户uin
+        :type source_account:      str
+        :rtype:
+        """
+        datasource_conn_info = self._get_wedata_security_auth_info(
+            wedata_id, source_account
+        )
         self._wedata_auth_info = datasource_conn_info
 
         if datasource_conn_info["auth_type"] == KERBEROS:
-            self._init_kerberos_ticket(datasource_conn_info["principal"], datasource_conn_info["keytab"])
-            conn = hive.connect(host=datasource_conn_info["host"], port=datasource_conn_info["port"], auth='KERBEROS',
-                                kerberos_service_name=datasource_conn_info["username"])
+            self._init_kerberos_ticket(
+                datasource_conn_info["principal"], datasource_conn_info["keytab"]
+            )
+            conn = hive.connect(
+                host=datasource_conn_info["host"],
+                port=datasource_conn_info["port"],
+                auth="KERBEROS",
+                kerberos_service_name=datasource_conn_info["username"],
+            )
         elif datasource_conn_info["auth_type"] == LDAP:
-            conn = hive.connect(host=datasource_conn_info["host"], port=datasource_conn_info["port"], auth='LDAP',
-                                username=datasource_conn_info["username"], password=datasource_conn_info["passwd"])
+            conn = hive.connect(
+                host=datasource_conn_info["host"],
+                port=datasource_conn_info["port"],
+                auth="LDAP",
+                username=datasource_conn_info["username"],
+                password=datasource_conn_info["passwd"],
+            )
         else:
             kwargs = {
                 "host": datasource_conn_info["host"],
@@ -351,52 +437,57 @@ class HiveInitial(object):
     def spark_hive_initial(self, emr_id, username=None, keytab=None):
         """为spark初始化emr hive（调用改方法后，就可以使用spark做hive操作）
 
-       :param emr_id:       腾讯云emr id
-       :type emr_id:        str
-       :param username:     如果使用kerberos认证，则需要传入对应用户名
-       :type username:      str
-       :param keytab:       keytab文件路径。如果使用集群默认账户（如hadoop），则需要提供keytab路径
-       :type keytab:        str
-       :rtype:
-       """
+        :param emr_id:       腾讯云emr id
+        :type emr_id:        str
+        :param username:     如果使用kerberos认证，则需要传入对应用户名
+        :type username:      str
+        :param keytab:       keytab文件路径。如果使用集群默认账户（如hadoop），则需要提供keytab路径
+        :type keytab:        str
+        :rtype:
+        """
         emr_conn_info = self._get_emr_security_auth_info(emr_id, username, keytab)
         if emr_conn_info["keytab"] != "":
-            self._init_kerberos_ticket(emr_conn_info["principal"], emr_conn_info["keytab"])
+            self._init_kerberos_ticket(username, emr_conn_info["keytab"])
 
     def hive_initial(self, emr_id, username=None, keytab=None):
         """获取emr hive连接句柄
 
-       :param emr_id:       腾讯云emr id
-       :type emr_id:        str
-       :param username:     如果使用kerberos认证，则需要传入对应用户名
-       :type username:      str
-       :param keytab:       keytab文件路径。如果使用集群默认账户（如hadoop），则需要提供keytab路径
-       :type keytab:        str
-       :rtype:
-       """
+        :param emr_id:       腾讯云emr id
+        :type emr_id:        str
+        :param username:     如果使用kerberos认证，则需要传入对应用户名
+        :type username:      str
+        :param keytab:       keytab文件路径。如果使用集群默认账户（如hadoop），则需要提供keytab路径
+        :type keytab:        str
+        :rtype:
+        """
         emr_conn_info = self._get_emr_security_auth_info(emr_id, username, keytab)
         if emr_conn_info["principal"] != "":
             service_name = (emr_conn_info["principal"].split("@")[0]).split("/")[0]
-            self._init_kerberos_ticket(emr_conn_info["principal"], emr_conn_info["keytab"])
-            return hive.connect(host=emr_conn_info["host"], port=emr_conn_info["port"], auth='KERBEROS',
-                                kerberos_service_name=service_name)
+            self._init_kerberos_ticket(username, emr_conn_info["keytab"])
+            return hive.connect(
+                host=emr_conn_info["host"],
+                port=emr_conn_info["port"],
+                auth="KERBEROS",
+                kerberos_service_name=service_name,
+            )
         else:
             return hive.connect(host=emr_conn_info["host"], port=emr_conn_info["port"])
 
     def hive_initial_custom(
-            self,
-            host=None,
-            port=None,
-            scheme=None,
-            username=None,
-            database='default',
-            auth=None,
-            configuration=None,
-            kerberos_service_name=None,
-            password=None,
-            check_hostname=None,
-            ssl_cert=None,
-            thrift_transport=None):
+        self,
+        host=None,
+        port=None,
+        scheme=None,
+        username=None,
+        database="default",
+        auth=None,
+        configuration=None,
+        kerberos_service_name=None,
+        password=None,
+        check_hostname=None,
+        ssl_cert=None,
+        thrift_transport=None,
+    ):
         """Connect to HiveServer2
 
         :param host: What host HiveServer2 runs on
@@ -425,10 +516,19 @@ class HiveInitial(object):
             password=password,
             check_hostname=check_hostname,
             ssl_cert=ssl_cert,
-            thrift_transport=thrift_transport)
+            thrift_transport=thrift_transport,
+        )
 
-    def upload_to_wedata_hive(self, wedata_id, local_path, table_name, database='default', overwrite=False,
-                              partition='', source_account=None):
+    def upload_to_wedata_hive(
+        self,
+        wedata_id,
+        local_path,
+        table_name,
+        database="default",
+        overwrite=False,
+        partition="",
+        source_account=None,
+    ):
         """上传文件到wedata hive
 
         :param wedata_id:       wedata 数据源id
@@ -455,24 +555,35 @@ class HiveInitial(object):
             hdfs_path = os.path.join(_get_tmp_path(), "result")
 
             def progress_callback(name, bytes):
-                pbar.update(2 ** 16)
-            with tqdm(total=size, unit='B', unit_scale=True) as pbar:
-                pbar.set_description('Uploading')
-                hdfs_client.upload(hdfs_path, local_path, progress=progress_callback, overwrite=True)
+                pbar.update(2**16)
+
+            with tqdm(total=size, unit="B", unit_scale=True) as pbar:
+                pbar.set_description("Uploading")
+                hdfs_client.upload(
+                    hdfs_path, local_path, progress=progress_callback, overwrite=True
+                )
 
             cursor.execute("USE " + database)
             sql = "LOAD DATA INPATH '{}' {} INTO TABLE {} {}".format(
                 hdfs_path,
                 "OVERWRITE" if overwrite else "",
                 table_name,
-                "" if partition == "" else "PARTITION (%s)" % partition
+                "" if partition == "" else "PARTITION (%s)" % partition,
             )
             print("导入hive中...")
             cursor.execute(sql)
             print("导入完成")
 
-    def export_from_wedata_hive(self, wedata_id, local_path, table_name='', database='default', sql='',
-                                row_format="row format delimited fields terminated by ','", source_account=None):
+    def export_from_wedata_hive(
+        self,
+        wedata_id,
+        local_path,
+        table_name="",
+        database="default",
+        sql="",
+        row_format="row format delimited fields terminated by ','",
+        source_account=None,
+    ):
         """导出wedata hive数据到本地
 
         :param wedata_id:       wedata 数据源id
@@ -498,27 +609,29 @@ class HiveInitial(object):
 
             cursor.execute("USE " + database)
             if sql == "":
-                execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} SELECT {} FROM {}".format(
-                    hdfs_path,
-                    row_format,
-                    "*",
-                    table_name
+                execute_sql = (
+                    "INSERT OVERWRITE DIRECTORY '{}' {} SELECT {} FROM {}".format(
+                        hdfs_path, row_format, "*", table_name
+                    )
                 )
             else:
                 execute_sql = "INSERT OVERWRITE DIRECTORY '{}' {} {}".format(
-                    hdfs_path,
-                    row_format,
-                    sql
+                    hdfs_path, row_format, sql
                 )
             print("导出到hdfs中...")
             cursor.execute(execute_sql)
             print("导出到hdfs完成")
 
             def progress_callback(name, bytes):
-                pbar.update(2 ** 16)
-            with tqdm(total=hdfs_client.status(hdfs_path)["length"], unit='B', unit_scale=True) as pbar:
-                pbar.set_description('Downloading')
-                hdfs_client.download(hdfs_path, local_path, progress=progress_callback, overwrite=True)
+                pbar.update(2**16)
+
+            with tqdm(
+                total=hdfs_client.status(hdfs_path)["length"], unit="B", unit_scale=True
+            ) as pbar:
+                pbar.set_description("Downloading")
+                hdfs_client.download(
+                    hdfs_path, local_path, progress=progress_callback, overwrite=True
+                )
 
     def _get_hive_conn_cache(self, wedata_id, source_account):
         # if wedata_id in self._hive_conn_cache:
@@ -535,7 +648,10 @@ class HiveInitial(object):
                 hdfs_address.append("http://" + v[1].text)
             if v[0].text == "dfs.namenode.kerberos.principal":
                 open_kerberos = True
-                self._init_kerberos_ticket(self._wedata_auth_info["principal"], self._wedata_auth_info["keytab"])
+                self._init_kerberos_ticket(
+                    self._wedata_auth_info["principal"],
+                    self._wedata_auth_info["keytab"],
+                )
 
         if not hdfs_address[0]:
             raise Exception("get hdfs address error")
@@ -555,7 +671,9 @@ class HiveInitial(object):
             "keytab": "",
         }
 
-        cred = credential.Credential(self._client_info["secret_id"], self._client_info["secret_key"])
+        cred = credential.Credential(
+            self._client_info["secret_id"], self._client_info["secret_key"]
+        )
         client = emr_client.EmrClient(cred, self._client_info["region"])
 
         node_req = emr_models.DescribeClusterNodesRequest()
@@ -571,7 +689,7 @@ class HiveInitial(object):
         conf_rsp = client.DescribeServiceConfs(conf_req)
         hive_site = hdfs_site = core_site = yarn_site = {}
         for v in conf_rsp.ServiceConfList:
-            tmp_param = json.loads(base64.b64decode(v.OriParam).decode('ascii'))
+            tmp_param = json.loads(base64.b64decode(v.OriParam).decode("ascii"))
 
             if v.FileName == "hdfs-site.xml":
                 for v1 in tmp_param:
@@ -607,9 +725,14 @@ class HiveInitial(object):
                     ret["principal"] = ret["principal"].replace("_HOST", master_host)
 
                 self._save_xml(hive_site, self._hive_site)
-                if "hive.server2.authentication" in hive_site and hive_site["hive.server2.authentication"] == "kerberos":
+                if (
+                    "hive.server2.authentication" in hive_site
+                    and hive_site["hive.server2.authentication"] == "kerberos"
+                ):
                     if not username:
-                        raise Exception("The authentication mode is Kerberos, username is required")
+                        raise Exception(
+                            "The authentication mode is Kerberos, username is required"
+                        )
                     if (username and username in ["root", "hadoop"]) and not keytab:
                         raise Exception("The %s account must have a KeyTab" % username)
                     if keytab:
@@ -630,7 +753,7 @@ class HiveInitial(object):
             if v.FileName == "krb5.conf":
                 realm = kdc = admin_server = ""
                 port = 88
-                tmp_param = json.loads(base64.b64decode(v.OriParam).decode('ascii'))
+                tmp_param = json.loads(base64.b64decode(v.OriParam).decode("ascii"))
                 for v1 in tmp_param:
                     if v1["Name"] == "active_kdc_server_ip":
                         kdc = v1["Value"]
@@ -646,7 +769,11 @@ class HiveInitial(object):
         kdc = %s
         admin_server = %s
     }
-[domain_realm]""" % (realm.upper(), kdc + ":" + port, admin_server)
+[domain_realm]""" % (
+                    realm.upper(),
+                    kdc + ":" + port,
+                    admin_server,
+                )
                 default_realm = "default_realm = " + realm.upper()
 
                 with open(self._krb_conf, "r") as f:
@@ -676,21 +803,24 @@ class HiveInitial(object):
 
     def _crete_default_xml(self, file):
         if not os.path.exists(file):
-            r = ET.Element('configuration')
+            r = ET.Element("configuration")
             t = ET.ElementTree(r)
             t.write(file)
 
     def _init_kerberos_ticket(self, principal, keytab):
-        active_str = 'kinit -kt {0} {1}'.format(keytab, principal)
+        active_str = "kinit -kt {0} {1}".format(keytab, principal)
         if os.system(active_str) != 0:
             raise Exception("kinit error")
 
     def _get_wedata_security_auth_info(self, wedata_id, source_account):
         # 获取数据源信息
-        datasource_rsp = self._call_inside_action("DescribeDatasource", {
-            "Id": wedata_id
-        })
-        if "Data" not in datasource_rsp["Response"] or not datasource_rsp["Response"]["Data"]:
+        datasource_rsp = self._call_inside_action(
+            "DescribeDatasource", {"Id": wedata_id}
+        )
+        if (
+            "Data" not in datasource_rsp["Response"]
+            or not datasource_rsp["Response"]["Data"]
+        ):
             raise Exception(datasource_rsp)
         if datasource_rsp["Response"]["Data"]["Type"] != "HIVE":
             raise Exception("datasource type is not HIVE")
@@ -699,10 +829,12 @@ class HiveInitial(object):
 
         # 自定义源
         if datasource["Category"] == "DB":
-            custom_file_rsp = self._call_inside_action("DescribeDataSourceConfigFiles", {
-                "Id": wedata_id
-            })
-            host, port, config_file_empty = self._save_config_files(custom_file_rsp, datasource["Category"])
+            custom_file_rsp = self._call_inside_action(
+                "DescribeDataSourceConfigFiles", {"Id": wedata_id}
+            )
+            host, port, config_file_empty = self._save_config_files(
+                custom_file_rsp, datasource["Category"]
+            )
 
             if params["authentication"] == "none":
                 return {
@@ -711,9 +843,9 @@ class HiveInitial(object):
                     "auth_type": NONE,
                     "keytab": "",
                     "principal": "",
-                    "username": "hadoop", #TODO 先默认使用hadoop用户
+                    "username": "hadoop",  # TODO 先默认使用hadoop用户
                     "passwd": "",
-                    "config_file_empty": config_file_empty
+                    "config_file_empty": config_file_empty,
                 }
             elif params["authentication"] == "Kerberos":
                 return {
@@ -722,9 +854,9 @@ class HiveInitial(object):
                     "auth_type": KERBEROS,
                     "keytab": self._keytab,
                     "principal": params["principal"],
-                    "username": "hadoop", #TODO 先默认使用hadoop用户
+                    "username": "hadoop",  # TODO 先默认使用hadoop用户
                     "passwd": "",
-                    "config_file_empty": config_file_empty
+                    "config_file_empty": config_file_empty,
                 }
             else:
                 raise Exception("Unsupported custom source authentication method")
@@ -732,17 +864,22 @@ class HiveInitial(object):
         # 系统源
         if source_account is None:
             raise Exception("Param source_account cannot be None")
-        sys_conf_file_rsp = self._call_inside_action("DescribeConfigFiles", {
-            "ClusterId": datasource["ClusterId"]
-        })
-        host, port, config_file_empty = self._save_config_files(sys_conf_file_rsp, datasource["Category"])
+        sys_conf_file_rsp = self._call_inside_action(
+            "DescribeConfigFiles", {"ClusterId": datasource["ClusterId"]}
+        )
+        host, port, config_file_empty = self._save_config_files(
+            sys_conf_file_rsp, datasource["Category"]
+        )
 
         # 安全认证
-        auth_rsp = self._call_inside_action("QueryAccountMapping", {
-            "clusterId": datasource["ClusterId"],
-            "projectId": datasource["OwnerProjectId"],
-            "sourceAccount": source_account,
-        })
+        auth_rsp = self._call_inside_action(
+            "QueryAccountMapping",
+            {
+                "clusterId": datasource["ClusterId"],
+                "projectId": datasource["OwnerProjectId"],
+                "sourceAccount": source_account,
+            },
+        )
         if "Data" not in auth_rsp or auth_rsp["Data"] is None:
             raise Exception(auth_rsp)
         auth_data = auth_rsp["Data"]
@@ -759,16 +896,20 @@ class HiveInitial(object):
             "port": port,
             "auth_type": auth_data["authenticationType"],
             "keytab": self._keytab,
-            "principal": auth_data["targetAccount"] + "@" + auth_data["clusterId"].upper(),
+            "principal": auth_data["targetAccount"]
+            + "@"
+            + auth_data["clusterId"].upper(),
             "username": auth_data["targetAccount"],
             "passwd": auth_data["securityKey"],
-            "config_file_empty": config_file_empty
+            "config_file_empty": config_file_empty,
         }
 
     def _call_inside_action(self, action, payload):
         req = models.DescribeInsideActionRequest()
         req.ActionParam = action
-        req.PayloadParam = base64.b64encode(json.dumps(payload).encode("utf-8")).decode('ascii')
+        req.PayloadParam = base64.b64encode(json.dumps(payload).encode("utf-8")).decode(
+            "ascii"
+        )
         rsp = self._client_info["tione_client"].DescribeInsideAction(req)
         return json.loads(rsp.Data)
 
@@ -820,10 +961,11 @@ class HiveInitial(object):
         return host, port, config_file == "" or len(config_file) == 0
 
     def _get_wedata_jwt_token(self, jwt_payload):
-        jwt_headers = {
-            "typ": "JWT",
-            "alg": "HS256"
-        }
-        jwt_token = "Bearer " + jwt.encode(payload=jwt_payload, key=self._jwt_key, algorithm='HS256',
-                                           headers=jwt_headers)
+        jwt_headers = {"typ": "JWT", "alg": "HS256"}
+        jwt_token = "Bearer " + jwt.encode(
+            payload=jwt_payload,
+            key=self._jwt_key,
+            algorithm="HS256",
+            headers=jwt_headers,
+        )
         return jwt_token
