@@ -34,12 +34,13 @@ except ImportError:
 from tikit import tencentcloud
 from tikit.tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
 from tikit.tencentcloud.common.exception import TencentCloudSDKException as SDKError
-from tikit.tencentcloud.common.http.request import ApiRequest
+from tikit.tencentcloud.common.http.request import ApiRequest, ResponsePrettyFormatter
 from tikit.tencentcloud.common.http.request import RequestInternal
-from tikit.tencentcloud.common.profile.client_profile import ClientProfile
+from tikit.tencentcloud.common.profile.client_profile import ClientProfile, RegionBreakerProfile
 from tikit.tencentcloud.common.sign import Sign
+from tikit.tencentcloud.common.circuit_breaker import CircuitBreaker
 
-warnings.filterwarnings("ignore")
+warnings.filterwarnings("ignore", module="tencentcloud", category=UserWarning)
 
 _json_content = 'application/json'
 _multipart_content = 'multipart/form-data'
@@ -68,9 +69,6 @@ class AbstractClient(object):
     FMT = '%(asctime)s %(process)d %(filename)s L%(lineno)s %(levelname)s %(message)s'
 
     def __init__(self, credential, region, profile=None):
-        if credential is None:
-            raise TencentCloudSDKException(
-                "InvalidCredential", "Credential is None or invalid")
         self.credential = credential
         self.region = region
         self.profile = ClientProfile() if profile is None else profile
@@ -79,9 +77,19 @@ class AbstractClient(object):
                                   req_timeout=self.profile.httpProfile.reqTimeout,
                                   proxy=self.profile.httpProfile.proxy,
                                   is_http=is_http,
-                                  certification=self.profile.httpProfile.certification)
+                                  certification=self.profile.httpProfile.certification,
+                                  pre_conn_pool_size=self.profile.httpProfile.pre_conn_pool_size)
         if self.profile.httpProfile.keepAlive:
             self.request.set_keep_alive()
+        self.circuit_breaker = None
+        if not self.profile.disable_region_breaker:
+            if self.profile.region_breaker_profile is None:
+                self.profile.region_breaker_profile = RegionBreakerProfile()
+            self.circuit_breaker = CircuitBreaker(self.profile.region_breaker_profile)
+        if self.profile.request_client:
+            self.request_client = self._sdkVersion + "; " + self.profile.request_client
+        else:
+            self.request_client = self._sdkVersion
 
     def _fix_params(self, params):
         if not isinstance(params, (dict,)):
@@ -119,7 +127,9 @@ class AbstractClient(object):
 
     def _build_req_inter(self, action, params, req_inter, options=None):
         options = options or {}
-        if self.profile.signMethod == "TC3-HMAC-SHA256" or options.get("IsMultipart") is True:
+        if options.get('SkipSign'):
+            self._build_req_without_signature(action, params, req_inter, options)
+        elif self.profile.signMethod == "TC3-HMAC-SHA256" or options.get("IsMultipart") is True:
             self._build_req_with_tc3_signature(action, params, req_inter, options)
         elif self.profile.signMethod in ("HmacSHA1", "HmacSHA256"):
             self._build_req_with_old_signature(action, params, req_inter)
@@ -129,7 +139,7 @@ class AbstractClient(object):
     def _build_req_with_old_signature(self, action, params, req):
         params = copy.deepcopy(self._fix_params(params))
         params['Action'] = action[0].upper() + action[1:]
-        params['RequestClient'] = self._sdkVersion
+        params['RequestClient'] = self.request_client
         params['Nonce'] = random.randint(1, sys.maxsize)
         params['Timestamp'] = int(time.time())
         params['Version'] = self._apiVersion
@@ -178,7 +188,7 @@ class AbstractClient(object):
         timestamp = int(time.time())
         req.header["Host"] = endpoint
         req.header["X-TC-Action"] = action[0].upper() + action[1:]
-        req.header["X-TC-RequestClient"] = self._sdkVersion
+        req.header["X-TC-RequestClient"] = self.request_client
         req.header["X-TC-Timestamp"] = str(timestamp)
         req.header["X-TC-Version"] = self._apiVersion
         if self.profile.unsignedPayload is True:
@@ -200,7 +210,7 @@ class AbstractClient(object):
             req.header["Content-Type"] = content_type + "; boundary=" + boundary
             req.data = self._get_multipart_body(params, boundary, options)
 
-        service = endpoint.split('.')[0]
+        service = self._service
         date = datetime.utcfromtimestamp(timestamp).strftime('%Y-%m-%d')
         signature = self._get_tc3_signature(params, req, date, service, options)
 
@@ -248,6 +258,49 @@ class AbstractClient(object):
 
         return Sign.sign_tc3(self.credential.secret_key, date, service, string2sign)
 
+    def _build_req_without_signature(self, action, params, req, options=None):
+        content_type = self._default_content_type
+        if req.method == 'GET':
+            content_type = _form_urlencoded_content
+        elif req.method == 'POST':
+            content_type = _json_content
+        options = options or {}
+        if options.get("IsMultipart"):
+            content_type = _multipart_content
+        if options.get("IsOctetStream"):
+            content_type = _octet_stream
+        req.header["Content-Type"] = content_type
+
+        if req.method == "GET" and content_type == _multipart_content:
+            raise SDKError("ClientError",
+                           "Invalid request method GET for multipart.")
+
+        endpoint = self._get_endpoint()
+        timestamp = int(time.time())
+        req.header["Host"] = endpoint
+        req.header["X-TC-Action"] = action[0].upper() + action[1:]
+        req.header["X-TC-RequestClient"] = self.request_client
+        req.header["X-TC-Timestamp"] = str(timestamp)
+        req.header["X-TC-Version"] = self._apiVersion
+        if self.profile.unsignedPayload is True:
+            req.header["X-TC-Content-SHA256"] = "UNSIGNED-PAYLOAD"
+        if self.region:
+            req.header['X-TC-Region'] = self.region
+        if self.profile.language:
+            req.header['X-TC-Language'] = self.profile.language
+
+        if req.method == 'GET':
+            params = copy.deepcopy(self._fix_params(params))
+            req.data = urlencode(params)
+        elif content_type == _json_content:
+            req.data = json.dumps(params)
+        elif content_type == _multipart_content:
+            boundary = uuid.uuid4().hex
+            req.header["Content-Type"] = content_type + "; boundary=" + boundary
+            req.data = self._get_multipart_body(params, boundary, options)
+
+        req.header["Authorization"] = "SKIP"
+
     # it must return bytes instead of string
     def _get_multipart_body(self, params, boundary, options=None):
         if options is None:
@@ -275,8 +328,9 @@ class AbstractClient(object):
         return body
 
     def _check_status(self, resp_inter):
-        if resp_inter.status != 200:
-            raise TencentCloudSDKException("ServerNetworkError", resp_inter.data)
+        if resp_inter.status_code != 200:
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp_inter))
+            raise TencentCloudSDKException("ServerNetworkError", resp_inter.content)
 
     def _format_sign_string(self, params):
         formatParam = {}
@@ -296,17 +350,116 @@ class AbstractClient(object):
             endpoint = self._get_service_domain()
         return endpoint
 
-    def call(self, action, params, options=None, headers=None):
+    def _check_error(self, resp):
+        ct = resp.headers.get('Content-Type')
+        if ct not in ('text/plain', _json_content):
+            return
+
+        data = json.loads(resp.content)
+        if "Error" in data["Response"]:
+            code = data["Response"]["Error"]["Code"]
+            message = data["Response"]["Error"]["Message"]
+            reqid = data["Response"]["RequestId"]
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+            raise TencentCloudSDKException(code, message, reqid)
+        if "DeprecatedWarning" in data["Response"]:
+            import warnings
+            warnings.filterwarnings("default")
+            warnings.warn("This action is deprecated, detail: %s" % data["Response"]["DeprecatedWarning"],
+                          DeprecationWarning)
+
+    @staticmethod
+    def _process_response_sse(resp):
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp, format_body=False))
+        e = {}
+
+        for line in resp.iter_lines():
+            if not line:
+                yield e
+                e = {}
+                continue
+
+            logger.debug("GetResponse: %s", line)
+            line = line.decode('utf-8')
+
+            # comment
+            if line[0] == ':':
+                continue
+
+            colon_idx = line.find(':')
+            key = line[:colon_idx]
+            val = line[colon_idx + 1:]
+            if key == 'data':
+                # The spec allows for multiple data fields per event, concatenated them with "\n".
+                if 'data' not in e:
+                    e['data'] = val
+                else:
+                    e['data'] += '\n' + val
+            elif key in ('event', 'id'):
+                e[key] = val
+            elif key == 'retry':
+                e[key] = int(val)
+
+    @staticmethod
+    def _process_response_json(resp, resp_type):
+        resp_obj = json.loads(resp.content)["Response"]
+        model = resp_type()
+        model._deserialize(resp_obj)
+        return model
+
+    def _call(self, action, params, options=None, headers=None):
+        if headers is None:
+            headers = {}
+        if not isinstance(headers, dict):
+            raise TencentCloudSDKException("ClientError", "headers must be a dict.")
+        if "x-tc-traceid" not in {k.lower() for k in headers.keys()}:
+            headers["X-TC-TraceId"] = str(uuid.uuid4())
+        if not self.profile.disable_region_breaker:
+            return self._call_with_region_breaker(action, params, options, headers)
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
                               self._requestPath,
                               header=headers)
         self._build_req_inter(action, params, req, options)
 
-        resp_inter = self.request.send_request(req)
-        self._check_status(resp_inter)
-        data = resp_inter.data
-        return data
+        if self.profile.httpProfile.apigw_endpoint:
+            req.host = self.profile.httpProfile.apigw_endpoint
+            req.header["Host"] = req.host
+        return self.request.send_request(req)
+
+    def call(self, action, params, options=None, headers=None):
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+        return resp.content
+
+    def _call_with_region_breaker(self, action, params, options=None, headers=None):
+        endpoint = self._get_endpoint()
+        generation, need_break = self.circuit_breaker.before_requests()
+        if need_break:
+            endpoint = self._service + "." + self.profile.region_breaker_profile.backup_endpoint
+        req = RequestInternal(endpoint,
+                              self.profile.httpProfile.reqMethod,
+                              self._requestPath,
+                              header=headers)
+        self._build_req_inter(action, params, req, options)
+        resp = None
+        try:
+            resp = self.request.send_request(req)
+            self.circuit_breaker.after_requests(generation, True)
+            return resp
+        except TencentCloudSDKException as e:
+            if resp and "RequestId" in resp.content and e.code != "InternalError":
+                self.circuit_breaker.after_requests(generation, True)
+            else:
+                self.circuit_breaker.after_requests(generation, False)
+
+    def call_with_region_breaker(self, action, params, options=None, headers=None):
+        resp = self._call_with_region_breaker(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return resp.content
 
     def call_octet_stream(self, action, headers, body):
         """
@@ -331,26 +484,18 @@ class AbstractClient(object):
 
         req = RequestInternal(self._get_endpoint(),
                               self.profile.httpProfile.reqMethod,
-                              self._requestPath)
-        for key in headers:
-            req.header[key] = headers[key]
+                              self._requestPath,
+                              header=headers)
         req.data = body
         options = {"IsOctetStream": True}
         self._build_req_inter(action, None, req, options)
 
         resp = self.request.send_request(req)
         self._check_status(resp)
-        data = resp.data
+        self._check_error(resp)
+        return json.loads(resp.content)
 
-        json_rsp = json.loads(data)
-        if "Error" in json_rsp["Response"]:
-            code = json_rsp["Response"]["Error"]["Code"]
-            message = json_rsp["Response"]["Error"]["Message"]
-            reqid = json_rsp["Response"]["RequestId"]
-            raise TencentCloudSDKException(code, message, reqid)
-        return json_rsp
-
-    def call_json(self, action, params, headers=None):
+    def call_json(self, action, params, headers=None, options=None):
         """
         Call api with json object and return with json object.
 
@@ -358,18 +503,36 @@ class AbstractClient(object):
         :param action: api name e.g. ``DescribeInstances``
         :type params: dict
         :param params: params with this action
-        :type header: dict
-        :param header: request header, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :type headers: dict
+        :param headers: request header, like {"X-TC-TraceId": "ffe0c072-8a5d-4e17-8887-a8a60252abca"}
+        :type options: dict
+        :param options: request options, like {"SkipSign": False, "IsMultipart": False, "IsOctetStream": False, "BinaryParams": []}
         """
-        body = self.call(action, params, headers=headers)
-        response = json.loads(body)
-        if "Error" not in response["Response"]:
-            return response
-        else:
-            code = response["Response"]["Error"]["Code"]
-            message = response["Response"]["Error"]["Message"]
-            reqid = response["Response"]["RequestId"]
-            raise TencentCloudSDKException(code, message, reqid)
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+        return json.loads(resp.content)
+
+    def call_sse(self, action, params, headers=None, options=None):
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return self._process_response_sse(resp)
+
+    def _call_and_deserialize(self, action, params, resp_type, headers=None, options=None):
+        resp = self._call(action, params, options, headers)
+        self._check_status(resp)
+        self._check_error(resp)
+        return self._process_response(resp, resp_type)
+
+    def _process_response(self, resp, resp_type):
+        if resp.headers.get('Content-Type') == "text/event-stream":
+            logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp, format_body=False))
+            return self._process_response_sse(resp)
+
+        logger.debug("GetResponse: %s", ResponsePrettyFormatter(resp))
+        return self._process_response_json(resp, resp_type)
 
     def set_stream_logger(self, stream=None, level=logging.DEBUG, log_format=None):
         """
@@ -406,7 +569,7 @@ class AbstractClient(object):
         log = logging.getLogger(LOGGER_NAME)
         log.setLevel(level)
         mb = 1024 * 1024
-        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512*mb, backupCount=10)
+        fh = logging.handlers.RotatingFileHandler(file_path, maxBytes=512 * mb, backupCount=10)
         fh.setLevel(level)
         if log_format is None:
             log_format = self.FMT
